==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UK">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Компонування</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Пересунути на передній план</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Пересунути вище</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Пересунути нижче</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Перемістити на задній план</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Вибрати це</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Колір тексту</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Розмір шрифту</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Початковий номер</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Коефіцієнт затемнення</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрити інші</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрити всі</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Закрити усі ліворуч</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Закрити усі праворуч</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Обрізати</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Видимість рамки і заповнення</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Рамка і заповнення</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Рамка без заповнення</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Без рамки і заповнення</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Ефекти зображення</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Без ефектів</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Відкидання тіні</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Відтінки сірого</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабувати зображення</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Зберігати пропорції</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Висота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Піксель</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Частка</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Наліпка</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Вибрати</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Перо</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Номер</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Прямокутна позначка</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Еліптична позначка</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Позначка пером</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Подвійна стрілка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Пряма</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Розмивання</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Нумерований вказівник</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Наліпка</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Пікселізація</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Вказівник з текстом</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Стрілка з текстом</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Стрілка з номером</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation>Масштаб</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.1.orig.tar.gz: kImageAnnotator-0.7.1/translations/kImageAnnotator_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UK">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Компонування</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Пересунути на передній план</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Пересунути вище</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Пересунути нижче</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Перемістити на задній план</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Вибрати це</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Керування</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Загальні параметри</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Параметри зображень</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Колір тексту</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Базове значення</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Коефіцієнт заплутування</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Тінь пункту</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Параметри пункту</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Непрозорість</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрити інші</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрити всі</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Закрити усі ліворуч</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Закрити усі праворуч</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Вибір інструмента</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Обрізати</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Масштабувати</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Обертати</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Змінити полотно</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Горизонтально</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Видимість рамки і заповнення</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Рамка і заповнення</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Рамка без заповнення</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Без рамки і заповнення</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Розмір шрифту</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Жирний</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Підкреслення</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Ефекти зображення</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Без ефектів</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Відкидання тіні</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Відтінки сірого</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Інвертувати кольори</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Обмеження</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Якщо увімкнено, примусово включати
до полотна фонове зображення.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Ш:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>В:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Колір:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Колір тла полотна</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Обертати зображення</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Довільне</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Додатні значення призводять до обертання за годинниковою стрілкою, від&apos;ємні — проти годинникової стрілки.
Обертання на кути, кратні до 90°, може призвести до втрати якості.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Горизонтально</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Обертати</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Перевернути</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Масштабувати зображення</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Зберігати пропорції</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Висота:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Піксель</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Частка</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Наліпка</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Вибрати</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Перо</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Номер</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Прямокутна позначка</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Еліптична позначка</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Позначка пером</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Подвійна стрілка</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Пряма</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Розмивання</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Нумерований вказівник</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Наліпка</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Пікселізація</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Вказівник з текстом</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Стрілка з текстом</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Стрілка з номером</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублювання</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Збільшити (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Зменшити (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Відновити масштаб (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Відновити масштаб</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>За зображенням</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Розмір зображення за областю перегляду (%1)</translation>
    </message>
</context>
</TS>
